@@ -18,7 +18,7 @@ from pip_services3_commons.config import IConfigurable
 from pip_services3_commons.data import PagingParams, DataPage
 from pip_services3_commons.errors import ConnectionException
 from pip_services3_commons.refer import IReferenceable, DependencyResolver, IReferences, IUnreferenceable
-from pip_services3_commons.reflect import PropertyReflector, RecursiveObjectWriter, ObjectWriter
+from pip_services3_commons.reflect import PropertyReflector
 from pip_services3_commons.run import IOpenable, ICleanable
 from pip_services3_components.log import CompositeLogger
 
@@ -280,7 +280,6 @@ class MongoDbPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpena
         uri = self._connection_resolver.resolve(correlation_id)
 
         max_pool_size = self._options.get_as_nullable_integer("max_pool_size")
-        keep_alive = self._options.get_as_nullable_boolean("keep_alive")
         connect_timeout = self._options.get_as_nullable_integer("connect_timeout")
         socket_timeout = self._options.get_as_nullable_integer("socket_timeout")
         auto_reconnect = self._options.get_as_nullable_boolean("auto_reconnect")
@@ -296,7 +295,6 @@ class MongoDbPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpena
             kwargs = {
                 'maxPoolSize': max_pool_size,
                 'connectTimeoutMS': connect_timeout,
-                'socketKeepAlive': keep_alive,
                 'socketTimeoutMS': socket_timeout,
                 'appname': correlation_id
             }
